==> scala-relay-compiler-0.6.13.tgz: package/src/transforms/SJSTransform.js <==
/**
 *  @flow
 */

const GraphQLCompilerContext = require('relay-compiler/lib/GraphQLCompilerContext');
const GraphQLIRTransformer = require('relay-compiler/lib/GraphQLIRTransformer');

const invariant = require('invariant');
const stableJSONStringify = require('relay-compiler/lib/stableJSONStringify');
// const stableJSONStringify = require('stableJSONStringify');

const {
  CompilerContext,
  IRTransformer,
  getLiteralArgumentValues,
} = require('relay-compiler/lib/GraphQLCompilerPublic');

function sjsTransform(
  context: GraphQLCompilerContext,
): GraphQLCompilerContext {

  return IRTransformer.transform(
    context,
    {
      Fragment: visitFragment,
      FragmentSpread: visitFragmentSpread,
    },
    () => ({}),
  );
}

const SJS = 'sjs';
const WITH = 'with';

function visitFragment(fragment: Fragment): Fragment {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({name}) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);
  
  return {
    ...transformedFrag,
    directives: transformedFrag.directives.filter(
      directive => directive.name !== SJS,
    ),
    metadata: {
      ...(transformedFrag.metadata || {}),
      ...arg,
    },
  };
}

function visitFragmentSpread(fragment: Fragment): Fragment {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({name}) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);
  
  return {
    ...transformedFrag,
    directives: transformedFrag.directives.filter(
      directive => directive.name !== SJS,
    ),
    metadata: {
      ...(transformedFrag.metadata || {}),
      ...arg,
    },
  };
}

function filterDirectivesTransform(
  context: GraphQLCompilerContext,
): GraphQLCompilerContext {
  return GraphQLIRTransformer.transform(
    context,
    {Directive: visitDirective},
    () => ({}),
  );
}

/**
 *
 * Skip directives not defined in the original schema.
 */
function visitDirective(directive: Directive): ?Directive {
  if (directive.name === SJS)
    return null;
  return directive;
}


module.exports = {
  transform: sjsTransform,
  transformRemoveSjs: filterDirectivesTransform,
};

==> scala-relay-compiler-0.9.0.tgz: package/src/transforms/SJSTransform.js <==
/**
 *  @flow
 */

const GraphQLCompilerContext = require('relay-compiler/lib/GraphQLCompilerContext');
const GraphQLIRTransformer = require('relay-compiler/lib/GraphQLIRTransformer');

const invariant = require('invariant');

import type {InlineFragment, Fragment, FragmentSpread, Directive, Field} from 'relay-compiler/lib/GraphQLIR';


const {
  CompilerContext,
  IRTransformer,
  getLiteralArgumentValues,
} = require('relay-compiler/lib/GraphQLCompilerPublic');

function sjsTransform(
  context: GraphQLCompilerContext,
): GraphQLCompilerContext {

  return IRTransformer.transform(
    context,
    {
      Fragment: visitField,
      FragmentSpread: visitField,
      InlineFragment: visitField,
      LinkedField: visitField,
    },
    () => ({}),
  );
}

const SJS = 'scalajs';

function visitField(fragment): any {
  let transformedFrag = this.traverse(fragment);
  const relayDirective = transformedFrag.directives.find(({name}) => name === SJS);
  if (!relayDirective) {
    return transformedFrag;
  }

  const arg = getLiteralArgumentValues(relayDirective.args);

  return {
    ...transformedFrag,
    directives: transformedFrag.directives.filter(
      directive => directive.name !== SJS,
    ),
    metadata: {
      ...(transformedFrag.metadata || {}),
      ...arg,
    },
  };
}

function filterDirectivesTransform(
  context: GraphQLCompilerContext,
): GraphQLCompilerContext {
  return GraphQLIRTransformer.transform(
    context,
    {Directive: visitDirective},
    () => ({}),
  );
}

/**
 *
 * Skip directives not defined in the original schema.
 */
function visitDirective(directive: Directive): ?Directive {
  if (directive.name === SJS)
    return null;
  return directive;
}


module.exports = {
  transform: sjsTransform,
  transformRemoveSjs: filterDirectivesTransform,
};
